{% extends 'generic/object.html' %}

{% block content %}
<div class="row">
	<div class="col col-md-12">
        <div class="card">
            <h5 class="card-header">
                Config
            </h5>
            <div class="card-body">
                <div class="change-data"><pre>{{backup_config}}</pre></div>
            </div>
        </div>
	</div>
</div>
{% endblock %}