# Generated by Django 3.2.8 on 2021-11-23 04:43

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('netbox_config_backup', '0004_custom_constraints'),
    ]

    operations = [
        migrations.AddField(
            model_name='backupcommit',
            name='time',
            field=models.DateTimeField(auto_now=True),
        ),
    ]
