# Generated by Django 3.2.8 on 2021-11-23 17:54

from django.db import migrations, models
import django.utils.timezone


class Migration(migrations.Migration):

    dependencies = [
        ('netbox_config_backup', '0006_backup_add_commit_last_time'),
    ]

    operations = [
        migrations.AddField(
            model_name='backupjob',
            name='scheduled',
            field=models.DateTimeField(auto_now_add=True, default=django.utils.timezone.now),
            preserve_default=False,
        ),
    ]
