# Generated by Django 3.2.8 on 2021-11-23 03:30

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('netbox_config_backup', '0003_primary_model_to_bigid'),
    ]

    operations = [
        migrations.AddConstraint(
            model_name='backupcommit',
            constraint=models.CheckConstraint(check=models.Q(('backup__isnull', False), ('sha__isnull', False)), name='backup_and_sha_not_null'),
        ),
    ]
